@@ -1,10 +1,11 @@
 package Software::Release::Watch::ExtractInfo::Filename;
 
-use 5.010;
-use Log::Any '$log';
-use Moo::Role;
+our $DATE = '2015-09-04'; # DATE
+our $VERSION = '0.04'; # VERSION
 
-our $VERSION = '0.03'; # VERSION
+use 5.010;
+use Log::Any::IfLOG '$log';
+use Moo::Role;
 
 #my @archive_exts = qw(tar.gz tar.bz2 tar zip rar);
 #my $archive_re   = join("|", map {quotemeta} @archive_exts);
@@ -39,7 +40,7 @@ Software::Release::Watch::ExtractInfo::Filename - Parse releases from name like
 
 =head1 VERSION
 
-This document describes version 0.03 of Software::Release::Watch::ExtractInfo::Filename (from Perl distribution Software-Release-Watch), released on 2014-08-16.
+This document describes version 0.04 of Software::Release::Watch::ExtractInfo::Filename (from Perl distribution Software-Release-Watch), released on 2015-09-04.
 
 =for Pod::Coverage extract_info
 
@@ -49,7 +50,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Software-R
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Software-Release-Watch>.
+Source repository is at L<https://github.com/perlancar/perl-Software-Release-Watch>.
 
 =head1 BUGS
 
@@ -61,11 +62,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
