@@ -5,7 +5,7 @@ use Moo::Role;
 
 use SemVer;
 
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 sub cmp_version {
     my ($a, $b) = @_;
@@ -27,7 +27,7 @@ Software::Release::Watch::Versioning::SemVer - Semantic versioning as per semver
 
 =head1 VERSION
 
-This document describes version 0.03 of Software::Release::Watch::Versioning::SemVer (from Perl distribution Software-Release-Watch), released on 2014-08-16.
+This document describes version 0.04 of Software::Release::Watch::Versioning::SemVer (from Perl distribution Software-Release-Watch), released on 2015-09-04.
 
 =for Pod::Coverage cmp_version
 
@@ -37,7 +37,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Software-R
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Software-Release-Watch>.
+Source repository is at L<https://github.com/perlancar/perl-Software-Release-Watch>.
 
 =head1 BUGS
 
@@ -49,11 +49,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
